@@ -28,7 +28,7 @@ var searchData=
   ['dbclrbuf_148',['dbclrbuf',['../a00545.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c'],['../a00545.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c']]],
   ['dbclropt_149',['dbclropt',['../a00545.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00545.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
   ['dbcmd_150',['dbcmd',['../a00545.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c'],['../a00545.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c']]],
-  ['dbcmdrow_151',['dbcmdrow',['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga8b263669ce0312e52b5ea42a57a56838',1,'DBCMDROW():&#160;sybdb.h']]],
+  ['dbcmdrow_151',['DBCMDROW',['../a00545.html#ga8b263669ce0312e52b5ea42a57a56838',1,'DBCMDROW():&#160;sybdb.h'],['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbcol_152',['DBCOL',['../a01328.html',1,'']]],
   ['dbcol2_153',['DBCOL2',['../a01332.html',1,'']]],
   ['dbcolinfo_154',['dbcolinfo',['../a00080.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c'],['../a00503.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c']]],
@@ -42,8 +42,8 @@ var searchData=
   ['dbconvert_162',['dbconvert',['../a00545.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c'],['../a00545.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c']]],
   ['dbconvert_5fps_163',['dbconvert_ps',['../a00545.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbproc, int db_srctype, const BYTE *src, DBINT srclen, int db_desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c'],['../a00545.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbprocess, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c']]],
   ['dbcount_164',['DBCOUNT',['../a00545.html#ga0ac1828f731a21c591c8d6330cbba3a9',1,'DBCOUNT():&#160;sybdb.h'],['../a00545.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c']]],
-  ['dbcurcmd_165',['DBCURCMD',['../a00545.html#gae375344b1ec50c1f756e3b69f3cef715',1,'DBCURCMD():&#160;sybdb.h'],['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c']]],
-  ['dbcurrow_166',['DBCURROW',['../a00545.html#gaf49e4b58918bfa4d4adaa14ee5bb375c',1,'DBCURROW():&#160;sybdb.h'],['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c']]],
+  ['dbcurcmd_165',['dbcurcmd',['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gae375344b1ec50c1f756e3b69f3cef715',1,'DBCURCMD():&#160;sybdb.h']]],
+  ['dbcurrow_166',['dbcurrow',['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaf49e4b58918bfa4d4adaa14ee5bb375c',1,'DBCURROW():&#160;sybdb.h']]],
   ['dbdata_167',['dbdata',['../a00545.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
   ['dbdatecmp_168',['dbdatecmp',['../a00550.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c'],['../a00550.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c']]],
   ['dbdatecrack_169',['dbdatecrack',['../a00545.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *datetime):&#160;dblib.c'],['../a00545.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *dt):&#160;dblib.c']]],
@@ -55,7 +55,7 @@ var searchData=
   ['dberrhandle_175',['dberrhandle',['../a00545.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c'],['../a00545.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c']]],
   ['dbexit_176',['dbexit',['../a00545.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit():&#160;dblib.c'],['../a00545.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit(void):&#160;dblib.c']]],
   ['dbfcmd_177',['dbfcmd',['../a00545.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c'],['../a00545.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c']]],
-  ['dbfirstrow_178',['dbfirstrow',['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga97a6493786124215ec9fe4b4bd2d7cbb',1,'DBFIRSTROW():&#160;sybdb.h']]],
+  ['dbfirstrow_178',['DBFIRSTROW',['../a00545.html#ga97a6493786124215ec9fe4b4bd2d7cbb',1,'DBFIRSTROW():&#160;sybdb.h'],['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbfreebuf_179',['dbfreebuf',['../a00545.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbgetchar_180',['dbgetchar',['../a00545.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbproc, int pos):&#160;dblib.c'],['../a00545.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbprocess, int n):&#160;dblib.c']]],
   ['dbgetmaxprocs_181',['dbgetmaxprocs',['../a00545.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c'],['../a00545.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c']]],
@@ -66,12 +66,12 @@ var searchData=
   ['dbgetuserdata_186',['dbgetuserdata',['../a00545.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbhasretstat_187',['dbhasretstat',['../a00546.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c'],['../a00546.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbinit_188',['dbinit',['../a00545.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c'],['../a00545.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c']]],
-  ['dbiordesc_189',['DBIORDESC',['../a00545.html#ga74ac942f9b7baa49e1d7d18628321297',1,'DBIORDESC():&#160;sybdb.h'],['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c']]],
-  ['dbiowdesc_190',['DBIOWDESC',['../a00545.html#ga5afb13924cda059d30be36a70dcf2cd9',1,'DBIOWDESC():&#160;sybdb.h'],['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c']]],
+  ['dbiordesc_189',['dbiordesc',['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga74ac942f9b7baa49e1d7d18628321297',1,'DBIORDESC():&#160;sybdb.h']]],
+  ['dbiowdesc_190',['dbiowdesc',['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga5afb13924cda059d30be36a70dcf2cd9',1,'DBIOWDESC():&#160;sybdb.h']]],
   ['dbisavail_191',['DBISAVAIL',['../a00545.html#ga40f6c951a851744e58ee715c652a8ac8',1,'sybdb.h']]],
   ['dbiscount_192',['dbiscount',['../a00545.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbisopt_193',['dbisopt',['../a00545.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00545.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
-  ['dblastrow_194',['dblastrow',['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga10b9b26cf9a901146e9675a9e678632b',1,'DBLASTROW():&#160;sybdb.h']]],
+  ['dblastrow_194',['DBLASTROW',['../a00545.html#ga10b9b26cf9a901146e9675a9e678632b',1,'DBLASTROW():&#160;sybdb.h'],['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dblib_2ec_195',['dblib.c',['../a00080.html',1,'']]],
   ['dblib_5fbuffer_5frow_196',['dblib_buffer_row',['../a00608.html',1,'']]],
   ['dblib_5fcontext_197',['dblib_context',['../a00612.html',1,'']]],
@@ -97,7 +97,7 @@ var searchData=
   ['dbmoney_217',['DBMONEY',['../a01300.html',1,'']]],
   ['dbmoney4_218',['DBMONEY4',['../a01304.html',1,'']]],
   ['dbmonthname_219',['dbmonthname',['../a00550.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c'],['../a00550.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c']]],
-  ['dbmorecmds_220',['DBMORECMDS',['../a00545.html#gad887bdce8cb0d3b8c6aaf659eb477b48',1,'DBMORECMDS():&#160;sybdb.h'],['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c']]],
+  ['dbmorecmds_220',['dbmorecmds',['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gad887bdce8cb0d3b8c6aaf659eb477b48',1,'DBMORECMDS():&#160;sybdb.h']]],
   ['dbmoretext_221',['dbmoretext',['../a00545.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c'],['../a00545.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c']]],
   ['dbmsghandle_222',['dbmsghandle',['../a00545.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c'],['../a00545.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c']]],
   ['dbname_223',['dbname',['../a00545.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c']]],
@@ -126,7 +126,7 @@ var searchData=
   ['dbretname_246',['dbretname',['../a00546.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
   ['dbretstatus_247',['dbretstatus',['../a00546.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c'],['../a00546.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbrettype_248',['dbrettype',['../a00546.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
-  ['dbrows_249',['dbrows',['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga48d71b32c26703c810191ef916c5448c',1,'DBROWS():&#160;sybdb.h']]],
+  ['dbrows_249',['DBROWS',['../a00545.html#ga48d71b32c26703c810191ef916c5448c',1,'DBROWS():&#160;sybdb.h'],['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c']]],
   ['dbrowtype_250',['DBROWTYPE',['../a00545.html#ga6fda3f4982dda5825d13fee392e89fd9',1,'DBROWTYPE():&#160;sybdb.h'],['../a00551.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbprocess):&#160;dblib.c']]],
   ['dbrpcinit_251',['dbrpcinit',['../a00546.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c'],['../a00546.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c']]],
   ['dbrpcparam_252',['dbrpcparam',['../a00546.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int db_type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c'],['../a00546.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c']]],
@@ -144,9 +144,9 @@ var searchData=
   ['dbsetllabeled_264',['DBSETLLABELED',['../a00551.html#gae52fc525116a3491c7e1092ad8257767',1,'sybdb.h']]],
   ['dbsetllong_265',['dbsetllong',['../a00551.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c'],['../a00551.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c']]],
   ['dbsetlname_266',['dbsetlname',['../a00551.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c'],['../a00551.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c']]],
-  ['dbsetlnatlang_267',['DBSETLNATLANG',['../a00545.html#gadada0e76c811a6fb84ce6759bcf116b5',1,'DBSETLNATLANG():&#160;sybdb.h'],['../a00545.html#ga30e0028e6208414c2245e5fcd6740d9d',1,'dbsetlnatlang():&#160;sybdb.h']]],
+  ['dbsetlnatlang_267',['dbsetlnatlang',['../a00545.html#ga30e0028e6208414c2245e5fcd6740d9d',1,'dbsetlnatlang():&#160;sybdb.h'],['../a00545.html#gadada0e76c811a6fb84ce6759bcf116b5',1,'DBSETLNATLANG():&#160;sybdb.h']]],
   ['dbsetlogintime_268',['dbsetlogintime',['../a00545.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c'],['../a00545.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c']]],
-  ['dbsetlpacket_269',['dbsetlpacket',['../a00545.html#ga0d0acc4ce2243e48023e022b50e2ac45',1,'dbsetlpacket():&#160;sybdb.h'],['../a00545.html#gae7e59f9c3cc0ec5916c06977ff7d8565',1,'DBSETLPACKET():&#160;sybdb.h']]],
+  ['dbsetlpacket_269',['DBSETLPACKET',['../a00545.html#gae7e59f9c3cc0ec5916c06977ff7d8565',1,'DBSETLPACKET():&#160;sybdb.h'],['../a00545.html#ga0d0acc4ce2243e48023e022b50e2ac45',1,'dbsetlpacket():&#160;sybdb.h']]],
   ['dbsetlpwd_270',['DBSETLPWD',['../a00544.html#ga61e04e8e2f0d7f1740d40634041f98eb',1,'sybdb.h']]],
   ['dbsetluser_271',['DBSETLUSER',['../a00544.html#gafbe7e48171d2f9b1d4f99e0bfdd98f5e',1,'sybdb.h']]],
   ['dbsetlversion_272',['DBSETLVERSION',['../a00551.html#ga7306859300823c120d807108a061c45a',1,'DBSETLVERSION():&#160;sybdb.h'],['../a00545.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c'],['../a00545.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c']]],
